"""Top-level package for Django Codemod."""

__author__ = """Bruno Alla"""
__email__ = "alla.brunoo@gmail.com"
__version__ = "0.1.1"
